@@ -28,8 +28,8 @@ stock_list %>%
 ## ------------------------------------------------------------------------
 tq_index("DOW", use_fallback = TRUE)
 
-## ------------------------------------------------------------------------
-tq_exchange("NYSE")
+## ---- eval=FALSE---------------------------------------------------------
+#  tq_exchange("NYSE")
 
 ## ------------------------------------------------------------------------
 tq_index("DOW", use_fallback = TRUE) %>%
@@ -42,7 +42,7 @@ tibble(symbol = c("AAPL", "GOOG", "AMZN", "FB")) %>%
 
 ## ------------------------------------------------------------------------
 c("AAPL", "GOOG") %>%
-    tq_get(get = c("stock.prices", "financials"))
+    tq_get(get = c("stock.prices", "dividends"))
 
 ## ------------------------------------------------------------------------
 data("FANG")
